# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: collector.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'collector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63ollector.proto\x12\tcollector\x1a\x1fgoogle/protobuf/timestamp.proto\"-\n\x18GetLatestReadingsRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"U\n\rSensorReading\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"G\n\x19GetLatestReadingsResponse\x12*\n\x08readings\x18\x01 \x03(\x0b\x32\x18.collector.SensorReading\"+\n\x15\x44\x65leteReadingsRequest\x12\x12\n\ndevice_ids\x18\x01 \x03(\t\")\n\x16\x44\x65leteReadingsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xc9\x01\n\x10\x43ollectorService\x12^\n\x11GetLatestReadings\x12#.collector.GetLatestReadingsRequest\x1a$.collector.GetLatestReadingsResponse\x12U\n\x0e\x44\x65leteReadings\x12 .collector.DeleteReadingsRequest\x1a!.collector.DeleteReadingsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'collector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETLATESTREADINGSREQUEST']._serialized_start=63
  _globals['_GETLATESTREADINGSREQUEST']._serialized_end=108
  _globals['_SENSORREADING']._serialized_start=110
  _globals['_SENSORREADING']._serialized_end=195
  _globals['_GETLATESTREADINGSRESPONSE']._serialized_start=197
  _globals['_GETLATESTREADINGSRESPONSE']._serialized_end=268
  _globals['_DELETEREADINGSREQUEST']._serialized_start=270
  _globals['_DELETEREADINGSREQUEST']._serialized_end=313
  _globals['_DELETEREADINGSRESPONSE']._serialized_start=315
  _globals['_DELETEREADINGSRESPONSE']._serialized_end=356
  _globals['_COLLECTORSERVICE']._serialized_start=359
  _globals['_COLLECTORSERVICE']._serialized_end=560
# @@protoc_insertion_point(module_scope)
